#!/bin/bash
#
# Copyright (C) 2010, 2021 Red Hat, Inc.
# Authors:
# Thomas Woerner <twoerner@redhat.com>
# Petr Pisar <ppisar@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

version=$1
[ -z "$version" ] && { echo "Usage: $0 <version>"; exit 1; }

# files to be removed without the main SDL-<version>/ prefix
declare -a REMOVE
for F in \
    share/html/css/ellipsis-xbl.xml \
    share/html/css/ui.jqgrid.css \
    share/html/css/ui.multiselect.css \
    share/html/js/i18n/grid.locale-ar.js.gz \
    share/html/js/i18n/grid.locale-bg.js.gz \
    share/html/js/i18n/grid.locale-bg1251.js.gz \
    share/html/js/i18n/grid.locale-cat.js.gz \
    share/html/js/i18n/grid.locale-cn.js.gz \
    share/html/js/i18n/grid.locale-cs.js.gz \
    share/html/js/i18n/grid.locale-da.js.gz \
    share/html/js/i18n/grid.locale-de.js.gz \
    share/html/js/i18n/grid.locale-dk.js.gz \
    share/html/js/i18n/grid.locale-el.js.gz \
    share/html/js/i18n/grid.locale-en.js.gz \
    share/html/js/i18n/grid.locale-es.js.gz \
    share/html/js/i18n/grid.locale-fa.js.gz \
    share/html/js/i18n/grid.locale-fi.js.gz \
    share/html/js/i18n/grid.locale-fr.js.gz \
    share/html/js/i18n/grid.locale-gl.js.gz \
    share/html/js/i18n/grid.locale-he.js.gz \
    share/html/js/i18n/grid.locale-hr.js.gz \
    share/html/js/i18n/grid.locale-hr1250.js.gz \
    share/html/js/i18n/grid.locale-hu.js.gz \
    share/html/js/i18n/grid.locale-id.js.gz \
    share/html/js/i18n/grid.locale-is.js.gz \
    share/html/js/i18n/grid.locale-it.js.gz \
    share/html/js/i18n/grid.locale-ja.js.gz \
    share/html/js/i18n/grid.locale-kr.js.gz \
    share/html/js/i18n/grid.locale-lt.js.gz \
    share/html/js/i18n/grid.locale-mne.js.gz \
    share/html/js/i18n/grid.locale-nl.js.gz \
    share/html/js/i18n/grid.locale-no.js.gz \
    share/html/js/i18n/grid.locale-pl.js.gz \
    share/html/js/i18n/grid.locale-pt-br.js.gz \
    share/html/js/i18n/grid.locale-pt.js.gz \
    share/html/js/i18n/grid.locale-ro.js.gz \
    share/html/js/i18n/grid.locale-ru.js.gz \
    share/html/js/i18n/grid.locale-sk.js.gz \
    share/html/js/i18n/grid.locale-sr.js.gz \
    share/html/js/i18n/grid.locale-sr-latin.js.gz \
    share/html/js/i18n/grid.locale-sv.js.gz \
    share/html/js/i18n/grid.locale-th.js.gz \
    share/html/js/i18n/grid.locale-tr.js.gz \
    share/html/js/i18n/grid.locale-tw.js.gz \
    share/html/js/i18n/grid.locale-ua.js.gz \
    share/html/js/i18n/grid.locale-vi.js.gz \
    share/html/js/jquery.jqGrid.min.js.gz \
    share/html/plugins/grid.addons.js.gz \
    share/html/plugins/grid.postext.js.gz \
    share/html/plugins/grid.setcolumns.js.gz \
    share/html/plugins/jquery.contextmenu.js.gz \
    share/html/plugins/jquery.searchFilter.js.gz \
    share/html/plugins/jquery.tablednd.js.gz \
    share/html/plugins/searchFilter.css \
    share/html/plugins/ui.multiselect.css \
    share/html/plugins/ui.multiselect.js.gz \
; do
    REMOVE[${#REMOVE[*]}]="$F"
done
# no changes below this line should be needed

orig="Mail-DMARC-${version}"
orig_tgz="${orig}.tar.gz"
repackaged="${orig}_repackaged"
repackaged_tar="${repackaged}.tar"
repackaged_tgz="${repackaged_tar}.gz"

# pre checks
[ ! -f "${orig_tgz}" ] && { echo "ERROR: ${orig_tgz} does not exist"; exit 1; }
[ -d "${orig}" ] && { echo "ERROR: ${orig} directory already exist"; exit 1; }
[ -f "${repackaged_tgz}" ] && { echo "ERROR: ${repackaged_tgz} already exist"; exit 1; }

# repackage
failure=0
tar -xzf "${orig_tgz}"
for file in "${REMOVE[@]}"; do
    rm --interactive=never "${orig}/${file}" 2>> repackage.log
    [ $? != 0 ] && { echo "ERROR: Could not remove ${orig}/${file} file."; failure=1; } || echo "${orig}/${file} removed."
done
[ $failure != 0 ] && { echo "See repackage.log for the details."; exit 1; }
tar -czf "${repackaged_tgz}" "${orig}"

# post checks
RET=0
for file in "${REMOVE[@]}"; do
    found=$(tar -ztvf "${repackaged_tgz}" | grep "${file}")
    [ -n "$found" ] && { echo "ERROR: file ${file} is still in the repackaged archive."; RET=1; }
done

[ $RET == 0 ] && echo "Sucessfully repackaged ${orig}: ${repackaged_tgz}"

exit $RET
